@@ -6,7 +6,7 @@
 ##   compiler and runtime and optionally an application.pl file with
 ##   a Logtalk application
 ## 
-##   Last updated on December 14, 2021
+##   Last updated on April 9, 2022
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
@@ -28,7 +28,7 @@
 
 
 print_version() {
-	echo "$(basename "$0") 0.1"
+	echo "$(basename "$0") 0.4"
 	exit 0
 }
 
@@ -100,7 +100,9 @@ fi
 
 # default values
 directory="$(pwd -P)"
-paths="$LOGTALKHOME/paths/paths_core.pl"
+temporary=""
+paths="$LOGTALKHOME/paths/paths.pl"
+settings="$LOGTALKHOME/scripts/embedding/settings-embedding-sample.lgt"
 compile="false"
 
 usage_help()
@@ -111,26 +113,28 @@ usage_help()
 	echo "given its loader file."
 	echo
 	echo "Usage:"
-	echo "  $(basename "$0") [-c] [-d directory] [-p paths] [-s settings] [-l loader]"
+	echo "  $(basename "$0") [-c] [-d directory] [-t tmpdir] [-p paths] [-s settings] [-l loader]"
 	echo "  $(basename "$0") -v"
 	echo "  $(basename "$0") -h"
 	echo
 	echo "Optional arguments:"
 	echo "  -c compile library alias paths in paths and settings files"
 	echo "  -d directory for generated Prolog files (absolute path; default is current directory)"
+	echo "  -t temporary directory for intermediate files (absolute path; default is an auto-created directory)"
 	echo "  -p library paths file (absolute path; default is $paths)"
-	echo "  -s settings file (absolute path)"
+	echo "  -s settings file (absolute path; default is $settings)"
 	echo "  -l loader file for the application (absolute path)"
 	echo "  -v print version of $(basename "$0")"
 	echo "  -h help"
 	echo
 }
 
-while getopts "cd:p:l:s:vh" option
+while getopts "cd:t:p:l:s:vh" option
 do
 	case $option in
 		c) compile="true";;
 		d) d_arg="$OPTARG";;
+		t) t_arg="$OPTARG";;
 		p) p_arg="$OPTARG";;
 		s) s_arg="$OPTARG";;
 		l) l_arg="$OPTARG";;
@@ -144,6 +148,10 @@ if [ "$d_arg" != "" ] ; then
 	directory="$d_arg"
 fi
 
+if [ "$t_arg" != "" ] ; then
+	temporary="$t_arg"
+fi
+
 if [ "$p_arg" != "" ] ; then
 	if [ -f "$p_arg" ] ; then
 		paths="$p_arg"
@@ -177,10 +185,15 @@ fi
 
 mkdir -p "$directory"
 
-temporary=$(mktemp -d)
+if [ "$temporary" != "" ] ; then
+	mkdir -p "$temporary"
+else
+	temporary=$(mktemp -d)
+fi
+
 if [[ ! "$temporary" || ! -d "$temporary" ]]; then
-  echo "Could not create temporary directory!"
-  exit 1
+	echo "Could not create temporary directory!"
+	exit 1
 fi
 
 cd "$temporary" || exit 1
@@ -225,7 +238,7 @@ if [ "$settings" != "" ] ; then
 		core_messages*_lgt.pl \
 		settings*.pl \
 		core.pl \
-		> logtalk.pl
+		> "$directory"/logtalk.pl
 else
 	cat \
 		trealla.pl \
@@ -237,16 +250,14 @@ else
 		logtalk*_lgt.pl \
 		core_messages*_lgt.pl \
 		core.pl \
-		> logtalk.pl
+		> "$directory"/logtalk.pl
 fi
 
-mv logtalk.pl "$directory"
-
 if [ "$loader" != "" ] ; then
 	mkdir -p "$temporary/application"
 	cd "$temporary/application" || exit 1
 	tpl -g "consult('$directory/logtalk'),set_logtalk_flag(clean,off),set_logtalk_flag(scratch_directory,'$temporary/application'),logtalk_load('$loader'),halt"
-	cat $(ls -rt "$temporary/application"/*.pl) > "$directory"/application.pl
+	cat $(ls -rt *.pl) > "$directory"/application.pl
 fi
 
 function cleanup {
