@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk installation script
-##   Last updated on March 22, 2022
+##   Last updated on September 20, 2022
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
@@ -37,11 +37,12 @@ fi
 cd "$(dirname "$0")" || exit 1
 
 version=$(cat ../VERSION.txt)
+version_base=$(cat ../VERSION.txt | cut -f1 -d"-")
 default_directory=logtalk-$version
 
 print_version() {
 	echo "Current $(basename "$0") version:"
-	echo "  0.8"
+	echo "  0.9"
 	exit 0
 }
 
@@ -166,6 +167,15 @@ for file in ../../logtalk/man/man1/*.1.gz ; do
 	ln -sf "$file" "$(basename "$file")"
 done
 
+mkdir -p ../../info
+cd ../../info || exit 1
+if [ -f ../logtalk/docs/LogtalkAPIs-$version_base.info ] ; then
+	ln -sf ../logtalk/docs/LogtalkAPIs-$version_base.info LogtalkAPIs.info
+fi
+if [ -f ../logtalk/manuals/TheLogtalkHandbook-$version_base.info ] ; then
+	ln -sf ../logtalk/manuals/TheLogtalkHandbook-$version_base.info TheLogtalkHandbook.info
+fi
+
 echo "The following integration scripts are installed for running Logtalk"
 echo "with selected backend Prolog compilers:"
 echo
@@ -181,7 +191,7 @@ echo "* Scryer Prolog (0.8.128 or later):  scryerlgt   (experimental)"
 echo "* SICStus Prolog (4.1.0 or later):   sicstuslgt"
 echo "* SWI-Prolog (6.6.0 or later):       swilgt"
 echo "* Tau Prolog (0.3.2 or later):       taulgt"
-echo "* Trealla Prolog (1.23.14 or later): tplgt       (experimental)"
+echo "* Trealla Prolog (2.2.5 or later):   tplgt       (experimental)"
 echo "* XSB (3.8.0 or later):              xsblgt      (first run may require sudo)"
 echo "* YAP (6.3.4 or later):              yaplgt"
 echo
