@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Unit testing automation script
-##   Last updated on January 24, 2022
+##   Last updated on April 26, 2022
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
@@ -26,7 +26,7 @@
 # loosely based on a unit test automation script contributed by Parker Jones
 
 print_version() {
-	echo "$(basename "$0") 10.1"
+	echo "$(basename "$0") 10.5"
 	exit 0
 }
 
@@ -113,11 +113,7 @@ run_testset() {
 		echo "% $unit_short"
 	fi
 	if [ -f "$driver.sh" ] ; then
-		if [ $# -eq 0 ] ; then
-			source "$driver.sh" -p $backend
-		else
-			source "$driver.sh" "$@"
-		fi
+		source "$driver.sh" "$@"
 		source_exit=$?
 		if [ "$source_exit" -gt 0 ] ; then
 			echo "%         source $driver.sh returned code $source_exit"
@@ -190,7 +186,7 @@ run_testset() {
 			echo "%         broken"
 		fi
 		ensure_format_report "$unit" "$(basename "$unit")" "Broken"
-	elif [ $tests_exit -eq 137 ] ; then
+	elif [ $tests_exit -eq 137 ] || [ $tests_exit -eq 124 ] ; then
 		if [ "$output" == 'verbose' ] ; then
 			echo "%         timeout"
 		fi
@@ -295,7 +291,7 @@ usage_help()
 	echo "The timeout option requires availability of the GNU coreutils timeout command."
 	echo
 	echo "Usage:"
-	echo "  $(basename "$0") -p prolog [-o output] [-m mode] [-f format] [-d results] [-t timeout] [-n driver] [-s prefix] [-u url] [-c report] [-l level] [-i options] [-g goal] [-r seed] [-w] [-- arguments]"
+	echo "  $(basename "$0") -p prolog [-o output] [-m mode] [-f format] [-d results] [-t timeout] [-n driver] [-s prefix] [-b tracker] [-u url] [-c report] [-l level] [-i options] [-g goal] [-r seed] [-w] [-- arguments]"
 	echo "  $(basename "$0") -v"
 	echo "  $(basename "$0") -h"
 	echo
@@ -324,7 +320,7 @@ usage_help()
 	echo "  -g initialization goal (default is $initialization_goal)"
 	echo "  -r random generator starting seed (no default)"
 	echo "  -w wipe default scratch directories (./.lgt_tmp and ./lgt_tmp) before running a test set"
-	echo "     (this option should not be used when running parallel proccess that use the same test sets)"
+	echo "     (this option should not be used when running parallel processes that use the same test sets)"
 	echo "  -- arguments to be passed to the tests (no default)"
 	echo "  -h help"
 	echo
@@ -362,7 +358,7 @@ if [ "$p_arg" == "" ] ; then
 	echo "Error! Backend Prolog compiler not specified!" >&2
 	usage_help
 	exit 1
-elif [ "$p_arg" == "b" ] || [ "$p_arg" == "b-prolog" ] ; then
+elif [ "$p_arg" == "b" ] ; then
 	backend=b
 	prolog='B-Prolog'
 	logtalk=bplgt$extension
@@ -372,7 +368,7 @@ elif [ "$p_arg" == "ciao" ] ; then
 	prolog='Ciao Prolog'
 	logtalk=ciaolgt$extension
 	logtalk_call="$logtalk $i_arg -e"
-elif [ "$p_arg" == "cx" ] || [ "$p_arg" == "cxprolog" ] ; then
+elif [ "$p_arg" == "cx" ] ; then
 	backend=cx
 	prolog='CxProlog'
 	logtalk=cxlgt$extension
@@ -382,12 +378,12 @@ elif [ "$p_arg" == "eclipse" ] ; then
 	prolog='ECLiPSe'
 	logtalk=eclipselgt$extension
 	logtalk_call="$logtalk $i_arg -e"
-elif [ "$p_arg" == "gnu" ] || [ "$p_arg" == "gnu-prolog" ] ; then
+elif [ "$p_arg" == "gnu" ] ; then
 	backend=gnu
 	prolog='GNU Prolog'
 	logtalk=gplgt$extension
 	logtalk_call="$logtalk $i_arg --query-goal"
-elif [ "$p_arg" == "ji" ] || [ "$p_arg" == "jiprolog" ] ; then
+elif [ "$p_arg" == "ji" ] ; then
 	backend=ji
 	prolog='JIProlog'
 	logtalk=jiplgt$extension
@@ -409,13 +405,13 @@ elif [ "$p_arg" == "scryer" ] ; then
 	prolog='Scryer Prolog'
 	logtalk=scryerlgt$extension
 	logtalk_call="$logtalk $i_arg -g"
-elif [ "$p_arg" == "sicstus" ] || [ "$p_arg" == "sicstus-prolog" ] ; then
+elif [ "$p_arg" == "sicstus" ] ; then
 	backend=sicstus
 	prolog='SICStus Prolog'
 	logtalk=sicstuslgt$extension
 	logtalk_call="$logtalk $i_arg --goal"
 	dot="."
-elif [ "$p_arg" == "swi" ] || [ "$p_arg" == "swi-prolog" ] ; then
+elif [ "$p_arg" == "swi" ] ; then
 	backend=swi
 	prolog='SWI-Prolog'
 	logtalk=swilgt$extension
